@@ -55,7 +55,7 @@ class UsrLog(models.Model):
     usr_insercao = models.IntegerField(null=True)
     usr_edicao = models.IntegerField(null=True)
     usr_delete = models.IntegerField(null=True)
-    # trocar por inteiro
+
     origem_insercao_codigo = models.CharField(null=True, max_length=200)
     origem_insercao_tipo = models.CharField(null=True, max_length=200, default='USR.PROFILE')
     origem_insercao = CompositeForeignKey('core.Tipo', on_delete=models.DO_NOTHING, null=True, related_name='%(app_label)s_%(class)s_origem_insercao', to_fields={
@@ -149,6 +149,8 @@ class PessoaLog(ContatoLog):
 
     dat_nasc = models.DateField(null=True)
 
+    imagem = models.FileField(upload_to='fotos/usuarios', default='fotos/no-photo.png', null=True)
+
     nm_mae = models.CharField(max_length=200, null=True)
     nm_pai = models.CharField(max_length=200, null=True)
 
@@ -303,6 +305,8 @@ class UF(Log):
     codigo = models.IntegerField(primary_key=True)
     nome = models.CharField(max_length=200, null=True)
     nm_abrev = models.CharField(max_length=2, null=True)
+    cep_faixa_ini = models.CharField(max_length=80, null=True)
+    cep_faixa_fim = models.CharField(max_length=80, null=True)
 
     class Meta(Log.Meta):
         abstract = False
@@ -313,6 +317,8 @@ class Municipio(Log):
     uf = models.ForeignKey('core.UF', on_delete=models.DO_NOTHING, null=True)
     codigo = models.IntegerField(primary_key=True)
     nome = models.CharField(max_length=200)
+    cep_faixa_ini = models.CharField(max_length=80, null=True)
+    cep_faixa_fim = models.CharField(max_length=80, null=True)
 
     class Meta(Log.Meta):
         abstract = False
